Module convert

Module convert 

Low-level protobuf conversion between seam model types and wire messages. Bidirectional mapping between seam model types and protobuf messages.

Constants

WIRE_VERSION
Wire schema version written by crate::ProtobufCodec.

Functions

from_proto
Convert a protobuf ReferenceManual into the seam model.
to_proto
Convert a ReferenceManual to its protobuf representation.